State

Enum State 

pub enum State {
    AppIdle,
    AppDetach,
    DfuIdle,
    DfuDnloadSync,
    DfuDnbusy,
    DfuDnloadIdle,
    DfuManifestSync,
    DfuManifest,
    DfuManifestWaitReset,
    DfuUploadIdle,
    DfuError,
    Other(u8),
}
DFU State.

Note: not the same as status!

Variants



AppIdle

Device is running its normal application.



AppDetach

Device is running its normal application, has received the DFU_DETACH request, and is waiting for a USB reset.



DfuIdle

Device is operating in the DFU mode and is waiting for requests.



DfuDnloadSync

Device has received a block and is waiting for the host to solicit the status via DFU_GETSTATUS.



DfuDnbusy

Device is programming a control-write block into its nonvolatile memories.



DfuDnloadIdle

Device is processing a download operation. Expecting DFU_DNLOAD requests.



DfuManifestSync

Device has received the final block of firmware from the host and is waiting for receipt of DFU_GETSTATUS to begin the Manifestation phase; or device has completed the Manifestation phase and is waiting for receipt of DFU_GETSTATUS. (Devices that can enter this state after the Manifestation phase set bmAttributes bit bitManifestationTolerant to 1.)



DfuManifest

Device is in the Manifestation phase. (Not all devices will be able to respond to DFU_GETSTATUS when in this state.)



DfuManifestWaitReset

Device has programmed its memories and is waiting for a USB reset or a power on reset. (Devices that must enter this state clear bitManifestationTolerant to 0.)



DfuUploadIdle

The device is processing an upload operation. Expecting DFU_UPLOAD requests.



DfuError

An error has occurred. Awaiting the DFU_CLRSTATUS request.



Other(u8)

Other ({0}).