Status

Enum Status 

pub enum Status {
Show 17 variants Ok, ErrTarget, ErrFile, ErrWrite, ErrErase, ErrCheckErased, ErrProg, ErrVerify, ErrAddress, ErrNotdone, ErrFirmware, ErrVendor, ErrUsbr, ErrPor, ErrUnknown, ErrStalledpkt, Other(u8),
}
DFU Status.

Note: not the same as state!

Variants



Ok

No error condition is present.



ErrTarget

File is not targeted for use by this device.



ErrFile

File is for this device but fails some vendor-specific verification test.



ErrWrite

Device is unable to write memory.



ErrErase

Memory erase function failed.



ErrCheckErased

Memory erase check failed.



ErrProg

Program memory function failed.



ErrVerify

Programmed memory failed verification.



ErrAddress

Cannot program memory due to received address that is out of range.



ErrNotdone

Received DFU_DNLOAD with wLength = 0, but device does not think it has all of the data yet.



ErrFirmware

Device’s firmware is corrupt. It cannot return to run-time (non-DFU) operations.



ErrVendor

iString indicates a vendor-specific error.



ErrUsbr

Device detected unexpected USB reset signaling.



ErrPor

Device detected unexpected power on reset.



ErrUnknown

Something went wrong, but the device does not know what it was.



ErrStalledpkt

Device stalled an unexpected request.



Other(u8)

Other ({0}).